@@ -17,7 +17,7 @@ font management application from the GNOME desktop
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/014/272/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
